@@ -8,7 +8,7 @@
 import collections
 
 from openpyxl.worksheet.worksheet import Worksheet
-from utils.tool import char_to_num
+from simple_export.utils.tool import char_to_num
 
 class dynamic_method():
 
